const crypt = require("crypto");
const db = require("../services/dbAccess.services");
const fs = require("fs/promises");

import { minifyMail } from "./minify.utils";
import { logger } from "./logger.utils";

// Checks users registration key against issued keys
async function isAuthed(uuid: string): Promise<boolean> {
  // Needs testing
  const q = {
    uuid: uuid,
  };
  const res = await db.query("users", q);
  logger.debug(res, "checkUser: DB Query Result");
  const authorized = res && res[0] && res[0].domain;
  if (authorized) db.userAtime(uuid);
  return authorized;
}

// Checks whether a registration request key is valid
async function checkRequest(key: string) {
  const collection = "registrations";
  const query = { uuid: key };
  const res = await db.query(collection, query);
  logger.debug(res, "checkRequest: DB Lookup result");
  const result =
    res.length > 0 && res[0].time
      ? { result: true, domain: res[0].domain }
      : { result: false };
  return result;
}

// Creates an API key for a user
async function generateKey() {
  return crypt.randomUUID();
}

export function generateCode(): string {
  const characters = 'ABCDEFGHJKLMNPQRSTUVWXYZ23456789';
  const codeLength = 6;

  let code = '';
  const bytes = crypt.randomBytes(codeLength); // Generate random bytes
  for (let i = 0; i < codeLength; i++) {
    const randomIndex = bytes[i] % characters.length; // Map bytes to characters
    code += characters.charAt(randomIndex);
  }

  return code;
}

async function generateConfirmationEmail(eml: string, uuid: string) {
  try {
    const htmlTpl = await fs.readFile("mail-templates/register.html", "utf-8");
    const htmlStr = htmlTpl.replace(/987654/g, uuid);
    const htmlMin = await minifyMail(htmlStr);
    const txtTpl = fs.readFile("mail-templates/register.txt", "utf-8");
    return {
      to: eml,
      subject: "OwlBoard Registration",
      text: (await txtTpl).replace(/987654/g, uuid),
      html: htmlMin,
    };
  } catch (err) {
    logger.error(
      err,
      "generateConfirmationEmail: Error rendering email templates"
    );
    return false;
  }
}

module.exports = {
  isAuthed,
  generateKey,
  generateConfirmationEmail,
  checkRequest,
  generateCode
};

export { isAuthed, generateKey, generateConfirmationEmail, checkRequest };
